@@ -1,11 +1,17 @@
 // Tipo Especial
 
 pub struct Temperature {
-	temperature_type: String,
-	value: f64,
+	pub temperature_type: String,
+	pub value: f64,
 }
 
 impl Temperature {
+	pub fn new() -> Temperature{
+		Temperature{
+			temperature_type: String::from("Celsius"),
+			value: 0.0,
+		}
+	}
 	pub fn to_fahrenheit(&self) -> f64 {
 		if self.temperature_type == String::from("Fahrenheit") {
 			return self.value;
